@@ -128,7 +128,7 @@
 #define HAVE_LIBGNUTLS 1
 
 /* Define to 1 if GnuTLS was built with pkcs11 support. */
-/* #undef HAVE_GNUTLS_PKCS11 */
+#define HAVE_GNUTLS_PKCS11 1
 
 /* Enable libnl support */
 #define HAVE_LIBNL 1
@@ -146,8 +146,8 @@
 /* #undef HAVE_SMI_VERSION_STRING */
 
 /* Define to use xxhash library */
-/* #undef HAVE_XXHASH */
-#define XXHASH_VERSION_STRING ""
+#define HAVE_XXHASH 1
+#define XXHASH_VERSION_STRING "0.8.3"
 
 /* Define to use zlib library */
 #define HAVE_ZLIB 1
@@ -171,10 +171,10 @@
 /* #undef HAVE_BROTLI */
 
 /* Define to use lz4 library */
-#define HAVE_LZ4 1
+/* #undef HAVE_LZ4 */
 
 /* Check for lz4frame */
-#define HAVE_LZ4FRAME_H 1
+/* #undef HAVE_LZ4FRAME_H */
 
 /* Define to use snappy library */
 /* #undef HAVE_SNAPPY */
@@ -259,7 +259,7 @@
 /* #undef HAVE_ILBC */
 
 /* Define to 1 if you have the opus library. */
-#define HAVE_OPUS 1
+/* #undef HAVE_OPUS */
 
 /* Define to 1 if you have the `setresgid' function. */
 #define HAVE_SETRESGID 1
